##############################################################################################
## 
## File name: joyce_braithwaite_jpr.do
## Date: 		  January 28, 2013
## Author: 		Kyle Joyce (kjoyce@ucdavis.edu)
## Purpose: 	Graphs Predicted Probabilities for "Geographic Proximity and Third Party Joiners 
##            in Militarized Interstate Disputes"
##				    The results are shown in Figures 1 and 2
## Requires: 	joyce_braithwaite_predicted_probabilities_lsg_jpr.csv
##            joyce_braithwaite_predicted_probabilities_conditional_jpr.csv
## Output: 		lsg_four_combined_common_noci.eps
##            conditional_four_combined_common.eps
##
##############################################################################################

library(gplots)

#Change working directory
#setwd("...")

##########################################################################
##### Read in file containing predicted probabilities for LSG models #####
##########################################################################

pred.probs.lsg <- read.csv("joyce_braithwaite_predicted_probabilities_lsg_jpr.csv",sep=",",header=T)

cinc.axis <- (pred.probs.lsg$cinc_axis)/1000

###########################################
##### Extract predicted probabilities #####
###########################################

#####Not Contiguous, Not Allied

#No LSG
plo.00.nolsg <- pred.probs.lsg$plo_00_nolsg
phi.00.nolsg <- pred.probs.lsg$phi_00_nolsg
p.00.nolsg <- pred.probs.lsg$p_00_nolsg

#LSG (initial belligerents)
plo.00.combined <- pred.probs.lsg$plo_00_combined
phi.00.combined <- pred.probs.lsg$phi_00_combined
p.00.combined <- pred.probs.lsg$p_00_combined

#LSG (MIDLOC, using WGS84)
plo.00.wgs84 <- pred.probs.lsg$plo_00_wgs84
phi.00.wgs84 <- pred.probs.lsg$phi_00_wgs84
p.00.wgs84 <- pred.probs.lsg$p_00_wgs84

#####Contiguous, Not Allied

#No LSG
plo.10.nolsg <- pred.probs.lsg$plo_10_nolsg
phi.10.nolsg <- pred.probs.lsg$phi_10_nolsg
p.10.nolsg <- pred.probs.lsg$p_10_nolsg

#LSG (initial belligerents)
plo.10.combined <- pred.probs.lsg$plo_10_combined
phi.10.combined <- pred.probs.lsg$phi_10_combined
p.10.combined <- pred.probs.lsg$p_10_combined

#LSG (MIDLOC, using WGS84)
plo.10.wgs84 <- pred.probs.lsg$plo_10_wgs84
phi.10.wgs84 <- pred.probs.lsg$phi_10_wgs84
p.10.wgs84 <- pred.probs.lsg$p_10_wgs84

#####Not Contiguous, Allied

#No LSG
plo.01.nolsg <- pred.probs.lsg$plo_01_nolsg
phi.01.nolsg <- pred.probs.lsg$phi_01_nolsg
p.01.nolsg <- pred.probs.lsg$p_01_nolsg

#LSG (initial belligerents)
plo.01.combined <- pred.probs.lsg$plo_01_combined
phi.01.combined <- pred.probs.lsg$phi_01_combined
p.01.combined <- pred.probs.lsg$p_01_combined

#LSG (MIDLOC, using WGS84)
plo.01.wgs84 <- pred.probs.lsg$plo_01_wgs84
phi.01.wgs84 <- pred.probs.lsg$phi_01_wgs84
p.01.wgs84 <- pred.probs.lsg$p_01_wgs84

#####Contiguous, Allied

#No LSG
plo.11.nolsg <- pred.probs.lsg$plo_11_nolsg
phi.11.nolsg <- pred.probs.lsg$phi_11_nolsg
p.11.nolsg <- pred.probs.lsg$p_11_nolsg

#LSG (initial belligerents)
plo.11.combined <- pred.probs.lsg$plo_11_combined
phi.11.combined <- pred.probs.lsg$phi_11_combined
p.11.combined <- pred.probs.lsg$p_11_combined

#LSG (MIDLOC, using WGS84)
plo.11.wgs84 <- pred.probs.lsg$plo_11_wgs84
phi.11.wgs84 <- pred.probs.lsg$phi_11_wgs84
p.11.wgs84 <- pred.probs.lsg$p_11_wgs84

#################################################################
#### Plot predicted probabilities for LSG models (Figure 1) #####
#################################################################

postscript("figures/lsg_four_combined_common_noci.eps", horizontal=FALSE, onefile=FALSE, width=6, height=6)

par(mfrow=c(2,2))

#####Not Contiguous, Not Allied
plot(cinc.axis,p.00.nolsg,type="l",col="black",xlab="Capability",lty=1,lwd=2,ylab="Predicted Probability of Joining",main="Not Contiguous, Not Allied",ylim=c(0,.3),yaxt="n")
temp <- c(0.0,0.1,0.2,0.3)
axis(2,temp)

lines(cinc.axis,p.00.combined,col="grey50",lwd=2,lty=1)
lines(cinc.axis,p.00.wgs84,col="grey",lwd=2,lty=1)

leg.txt <- c("No LSG\nAdjustment","LSG Adjustment\nUsing Distance to\nInitial Belligerents","LSG Adjustment\nUsing Distance to\nMID Location")
legend(0,0.34,leg.txt,fill=c("black","grey50","grey"),cex=0.75,y.intersp=2,adj=c(0,0.5),bty="n")

box()

#####Contiguous, Not Allied
plot(cinc.axis,p.10.nolsg,type="l",col="black",xlab="Capability",lty=1,lwd=2,ylab="Predicted Probability of Joining",main="Contiguous, Not Allied",ylim=c(0,.3),yaxt="n")
temp <- c(0.0,0.1,0.2,0.3)
axis(2,temp)

lines(cinc.axis,p.10.combined,col="grey50",lwd=2,lty=1)
lines(cinc.axis,p.10.wgs84,col="grey",lwd=2,lty=1)

box()

#####Not Contiguous, Allied
plot(cinc.axis,p.01.nolsg,type="l",col="black",xlab="Capability",lty=1,lwd=2,ylab="Predicted Probability of Joining",main="Not Contiguous, Allied",ylim=c(0,.3),yaxt="n")
temp <- c(0.0,0.1,0.2,0.3)
axis(2,temp)

lines(cinc.axis,p.01.combined,col="grey50",lwd=2,lty=1)
lines(cinc.axis,p.01.wgs84,col="grey",lwd=2,lty=1)

box()

#####Contiguous, Allied
plot(cinc.axis,p.11.nolsg,type="l",col="black",xlab="Capability",lty=1,lwd=2,ylab="Predicted Probability of Joining",main="Contiguous, Allied",ylim=c(0,.3),yaxt="n")
temp <- c(0.0,0.1,0.2,0.3)
axis(2,temp)

lines(cinc.axis,p.11.combined,col="grey50",lwd=2,lty=1)
lines(cinc.axis,p.11.wgs84,col="grey",lwd=2,lty=1)

box()

dev.off()

##################################################################################
##### Read in file containing predicted probabilities for conditional models #####
##################################################################################

pred.probs.cond <- read.csv("joyce_braithwaite_predicted_probabilities_conditional_jpr.csv",sep=",",header=T)

dist.axis <- pred.probs.cond$dist_axis

###########################################
##### Extract predicted probabilities #####
###########################################

plo.00 <- pred.probs.cond$plo_00
phi.00 <- pred.probs.cond$phi_00
p.00 <- pred.probs.cond$p_00

plo.10 <- pred.probs.cond$plo_10
phi.10 <- pred.probs.cond$phi_10
p.10 <- pred.probs.cond$p_10

plo.01 <- pred.probs.cond$plo_01
phi.01 <- pred.probs.cond$phi_01
p.01 <- pred.probs.cond$p_01

plo.11 <- pred.probs.cond$plo_11
phi.11 <- pred.probs.cond$phi_11
p.11 <- pred.probs.cond$p_11

#########################################################################
#### Plot predicted probabilities for conditional models (Figure 2) #####
#########################################################################

postscript("figures/conditional_four_combined_common.eps", horizontal=FALSE, onefile=FALSE, width=6, height=6)

par(mfrow=c(2,2))

#####Not Contiguous, Not Allied

plot(dist.axis,phi.00,type="n",col="black",xlab="Distance to MID Location",lty=1,lwd=2,ylab="Predicted Probability of Joining",ylim=c(0,.05),main="Not Contiguous, Not Allied",xaxt="n",yaxt="n")

i.for <- order(dist.axis)
i.back <- order(dist.axis,decreasing=TRUE)

x.polygon.1 <- c(dist.axis[i.for][1:19983],dist.axis[i.back][1:19983])
y.polygon.1 <- c(phi.00[1:19983][i.for],plo.00[1:19983][i.back])
y.polygon.1 <- na.omit(y.polygon.1)
polygon(x.polygon.1,y.polygon.1,col="grey",border=NA)

lines(dist.axis,p.00,col="black",lwd=2,lty=3)
lines(dist.axis,phi.00,col="black",lwd=2,lty=1)
lines(dist.axis,plo.00,col="black",lwd=2,lty=1)

temp <- c(0,5000,10000,15000,20000)
axis(1,temp,cex.axis=.8)

temp2 <- c(0,0.01,0.02,0.03,0.04,0.05)
axis(2,temp2,cex.axis=.7)

box()

#####Contiguous, Not Allied
plot(dist.axis,phi.10,type="n",col="black",xlab="Distance to MID Location",lty=1,lwd=2,ylab="Predicted Probability of Joining",ylim=c(0,.05),main="Contiguous, Not Allied",xaxt="n",yaxt="n")

i.for <- order(dist.axis)
i.back <- order(dist.axis,decreasing=TRUE)

x.polygon.1 <- c(dist.axis[i.for][1:19983],dist.axis[i.back][1:19983])
y.polygon.1 <- c(phi.10[1:19983][i.for],plo.10[1:19983][i.back])
y.polygon.1 <- na.omit(y.polygon.1)
polygon(x.polygon.1,y.polygon.1,col="grey",border=NA)

lines(dist.axis,p.10,col="black",lwd=2,lty=3)
lines(dist.axis,phi.10,col="black",lwd=2,lty=1)
lines(dist.axis,plo.10,col="black",lwd=2,lty=1)

temp <- c(0,5000,10000,15000,20000)
axis(1,temp,cex.axis=.8)

temp2 <- c(0,0.01,0.02,0.03,0.04,0.05)
axis(2,temp2,cex.axis=.7)

box()

#####Not Contiguous, Allied
plot(dist.axis,phi.01,type="n",col="black",xlab="Distance to MID Location",lty=1,lwd=2,ylab="Predicted Probability of Joining",ylim=c(0,.05),main="Not Contiguous, Allied",xaxt="n",yaxt="n")

i.for <- order(dist.axis)
i.back <- order(dist.axis,decreasing=TRUE)

x.polygon.1 <- c(dist.axis[i.for][1:19983],dist.axis[i.back][1:19983])
y.polygon.1 <- c(phi.01[1:19983][i.for],plo.01[1:19983][i.back])
y.polygon.1 <- na.omit(y.polygon.1)
polygon(x.polygon.1,y.polygon.1,col="grey",border=NA)

lines(dist.axis,p.01,col="black",lwd=2,lty=3)
lines(dist.axis,phi.01,col="black",lwd=2,lty=1)
lines(dist.axis,plo.01,col="black",lwd=2,lty=1)

temp <- c(0,5000,10000,15000,20000)
axis(1,temp,cex.axis=.8)

temp2 <- c(0,0.01,0.02,0.03,0.04,0.05)
axis(2,temp2,cex.axis=.7)

box()

#####Contiguous, Allied
plot(dist.axis,phi.11,type="n",col="black",xlab="Distance to MID Location",lty=1,lwd=2,ylab="Predicted Probability of Joining",ylim=c(0,.05),main="Contiguous, Allied",xaxt="n",yaxt="n")

i.for <- order(dist.axis)
i.back <- order(dist.axis,decreasing=TRUE)

x.polygon.1 <- c(dist.axis[i.for][1:19983],dist.axis[i.back][1:19983])
y.polygon.1 <- c(phi.11[1:19983][i.for],plo.11[1:19983][i.back])
y.polygon.1 <- na.omit(y.polygon.1)
polygon(x.polygon.1,y.polygon.1,col="grey",border=NA)

lines(dist.axis,p.11,col="black",lwd=2,lty=3)
lines(dist.axis,phi.11,col="black",lwd=2,lty=1)
lines(dist.axis,plo.11,col="black",lwd=2,lty=1)

temp <- c(0,5000,10000,15000,20000)
axis(1,temp,cex.axis=.8)

temp2 <- c(0,0.01,0.02,0.03,0.04,0.05)
axis(2,temp2,cex.axis=.7)

box()

dev.off()